package com.zjsgfa.project.zjsgfa.service;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.BizTodoItem;

/**
 * 待办事项Service接口
 * 
 * @author ruoyi
 * @date 2026-02-11
 */
public interface IBizTodoItemService 
{
    /**
     * 查询待办事项
     * 
     * @param id 待办事项主键
     * @return 待办事项
     */
    public BizTodoItem selectBizTodoItemById(Long id);

    /**
     * 查询待办事项列表
     * 
     * @param bizTodoItem 待办事项
     * @return 待办事项集合
     */
    public List<BizTodoItem> selectBizTodoItemList(BizTodoItem bizTodoItem);

    /**
     * 新增待办事项
     * 
     * @param bizTodoItem 待办事项
     * @return 结果
     */
    public int insertBizTodoItem(BizTodoItem bizTodoItem);

    /**
     * 修改待办事项
     * 
     * @param bizTodoItem 待办事项
     * @return 结果
     */
    public int updateBizTodoItem(BizTodoItem bizTodoItem);

    /**
     * 批量删除待办事项
     * 
     * @param ids 需要删除的待办事项主键集合
     * @return 结果
     */
    public int deleteBizTodoItemByIds(Long[] ids);

    /**
     * 删除待办事项信息
     * 
     * @param id 待办事项主键
     * @return 结果
     */
    public int deleteBizTodoItemById(Long id);


    int insertTodoItem(String instanceId, String itemName, String itemContent, String module,String comment);

    List<BizTodoItem> selectBizTodoItemList2(BizTodoItem bizTodoItem);


    List<BizTodoItem> selectBizTodoItemListbyinstanceId(BizTodoItem query);

}
